@@ -17,6 +17,6 @@ def install():
         subprocess.call(["/usr/bin/open",os.path.dirname(__file__)+"/driver/ch34x_install.pkg"])
     elif sys=="Windows":
         subprocess.call([os.path.dirname(__file__)+"/driver/ch34x_install.exe"])
-    while exist():
+    while not exist():
         sleep(1)
     return
\ No newline at end of file
